# Example showing use of implicit function for clipping a dataset.
# view.
# Pipeline:
# SphereSource --> Clip --> (Representation, RenderView)
#        Plane -->

from paraview import servermanager

# We create a server connection only if one isn't already present.
if not servermanager.ActiveConnection:
  servermanager.Connect()

# First create a data source -- in this example we are simply rendering a sphere
# so we create a sphere source.

# Default parameter values can be specified as arguments to the constructor.
sphere = servermanager.sources.SphereSource(Radius=10.5)
# Parameter values can later be accessed/changed as follows:
sphere.PhiResolution = 200
sphere.ThetaResolution = 200


# Create the clip filter.
clipper = servermanager.filters.Clip()

# Set the input to the clip filter.
clipper.Input = sphere

# Now create the implicit function needed by the clip filter. Here we are
# clipping by an implicit plane.
plane = servermanager.implicit_functions.Plane(Normal=[0.5, 0.5, 0])

# Assign the clip function.
clipper.ClipFunction = plane

# Now create a view to show the data in.
view = servermanager.CreateRenderView()

# A representation maps the data produced by a source/filter to the view.
# So to show the data in a view, we need to create a representation for it.
reprClip = servermanager.CreateRepresentation(clipper, view)

# Reset the camera position so that all data is visible
view.ResetCamera()

# Render
view.StillRender()

raw_input("Hit 'Enter' to continue: ")
