# Example illustrating making the GUI aware of objects created through python.

import exceptions
from paraview import servermanager

# We create a server connection only if one isn't already present.
# This is never needed when running the script through the GUI.
if not servermanager.ActiveConnection:
  servermanager.Connect()

# Create a sphere
sphere = servermanager.sources.SphereSource(PhiResolution=20,\
  ThetaResolution=20)

# Register the sphere so that the GUI can access it through the proxy manager.
servermanager.Register(sphere, registrationName="SphereFromPython")

# Get the first render view in the GUI.
gui_view = servermanager.GetRenderView()

# Show the sphere in that view.
repr1 = servermanager.CreateRepresentation(sphere, gui_view)

# Make the GUI aware of this representation.
servermanager.Register(repr1)

repr1.Representation = "Wireframe"

# Create a new view
view2 = servermanager.CreateRenderView()
servermanager.Register(view2)

repr2 = servermanager.CreateRepresentation(sphere, view2)
servermanager.Register(repr2)

view2.ResetCamera()
