# Example for reading an exodus file.


import exceptions
from paraview import servermanager


filename = "VisExamples/can.ex2"
try:
  fp = open(filename, "r")
  fp.close()
except:
  raise exceptions.RuntimeError, \
    "Please set the filename to point to 'can.ex2'"

# We create a server connection only if one isn't already present.
if not servermanager.ActiveConnection:
  servermanager.Connect()

# Create the reader and set the filename. 
reader = servermanager.sources.ExodusIIReader(FileName=filename)

# Exodus belong to the category of readers where the user needs to choose the
# arrays that the reader should read. So before we can enable the arrays to
# read, we need to determine what arrays are available to us.

# Requests the reader to read the file meta-data and then provide information to
# the client.
reader.UpdatePipelineInformation()

# In case of ExodusIIReader, information about point arrays is available in
# PointResultArrayInfo while to choose the point arrays to read, one uses
# PointResultArrayStatus. 
# Similarly for Edge arrays, we have EdgeResultArrayInfo, and 
# EdgeResultArrayStatus etc.
# Here we want to enable all point arrays.
# PointResultArrayInfo and PointResultArrayStatus is a list with values as such 
#  [array_name0, status0, array_name1, status1 ... ].
point_array_info = reader.PointResultArrayInfo.GetData()
point_array_stats = []
for i in range(0, len(point_array_info), 2):
  array_name = point_array_info[i]
  point_array_stats.append(array_name)
  point_array_stats.append("1") ;# since we want to enable the array
print "Point Status set to: %s" % str(point_array_stats)
reader.PointResultArrayStatus = point_array_stats


# The usual stuff--create a view and representation to show the data the reader
# read.
view = servermanager.CreateRenderView()
repr = servermanager.CreateRepresentation(reader, view)

# Reset the camera so that the entire dataset is visible and then render the
# scene.
view.ResetCamera()

# Rotate the camera so that we are looking at the data head-on
view.GetActiveCamera().Elevation(90)
view.StillRender()

# This is a helper function to animate over the timesteps provided by the
# reader.
#servermanager.AnimateReader(reader, view)

# Suppose we want to see the last timestep
view.ViewTime = reader.TimestepValues.GetData()[-1]
print "*** Showing Time: %f" % view.ViewTime.GetData()
view.StillRender()


raw_input("Hit 'Enter' to continue: ")

