# Example for reading a *.vtk file
# This example also uses data information to determine the data value range for
# a point-data array

import exceptions
from paraview import servermanager

# TODO: Set the path to the blow.vtk file
filename = "VisExamples/blow.vtk"

# We create a server connection only if one isn't already present.
if not servermanager.ActiveConnection:
  servermanager.Connect()

try:
  fp = open(filename, "r")
  fp.close()
except:
  raise exceptions.RuntimeError, \
    "Please set the filename to point to 'blow.vtk'"

# Create the reader and set the filename. 
reader = servermanager.sources.LegacyVTKFileReader(FileNames=filename)

# The usual stuff--create a view and representation to show the data the reader
# read.
view = servermanager.CreateRenderView()
repr = servermanager.CreateRepresentation(reader, view)

# Let's use data information to determine if we can color by array named
# "displacement9" and then use the array information to determine the 
# data range to set up the lookup table.

# This will update the reader.
reader.UpdatePipeline()
dataInfo = reader.GetDataInformation()
pointDataInfo = dataInfo.GetPointDataInformation()
arrayInfo = pointDataInfo.GetArrayInformation("displacement9")
if arrayInfo:
  range = arrayInfo.GetComponentRange(-1) # get the range for the magnitude of
                                          # displacement9
  print range
  # Now create a lookup-table to map the scalar values to colors.
  lut = servermanager.rendering.PVLookupTable()
  lut.RGBPoints  = [range[0], 0.0, 0.0, 1.0,
                    range[1], 1.0, 0.0, 0.0]

  # Since we want to color by the magnitude of the "displacement9" array
  lut.VectorMode = "Magnitude" 

  # Assign the lookup table
  repr.LookupTable = lut
  repr.ColorArrayName = "displacement9"
  repr.ColorAttributeType = "POINT_DATA"

# Reset the camera so that the entire dataset is visible and then render the
# scene.
view.ResetCamera()

# Rotate the camera so that we are looking at the data head-on
view.GetActiveCamera().Azimuth(90)
view.StillRender()

raw_input("Hit 'Enter' to continue: ")

