# Example for reading a *.vtk file series and then animating through the entire
# series.

import exceptions
from paraview import servermanager

# TODO: Set the path to the blow.vtk file
filenamePrefix = "VisExamples/FileSeries"
filenames = []
for i in range(16):
  cur_name = "%s/blow%d.vtk" % (filenamePrefix, i)
  try:
    fp = open(cur_name, "r")
    fp.close()
    filenames.append(cur_name)
  except:
    pass

if not filenames:
  raise exceptions.RuntimeError, \
    "Please set the filenamePrefix to point to directory containing 'blow0.vtk"

# We create a server connection only if one isn't already present.
if not servermanager.ActiveConnection:
  servermanager.Connect()

# Create the reader and set the filename. 
reader = servermanager.sources.LegacyVTKFileReader(FileNames=filenames)

# WarpVector filter tranforms the input geometry using a vector array.
warpVector = servermanager.filters.WarpVector(Input=reader)
warpVector.SelectInputVectors[4] = "displacement"

# The usual stuff--create a view and representation to show the data the reader
# read.
view = servermanager.CreateRenderView()
repr = servermanager.CreateRepresentation(warpVector, view)

# Reset the camera so that the entire dataset is visible and then render the
# scene.
view.ResetCamera()

# Rotate the camera so that we are looking at the data head-on
view.GetActiveCamera().Azimuth(90)
view.StillRender()

# This is a helper function to animate over the timesteps provided by the
# reader.
servermanager.AnimateReader(reader, view)

raw_input("Hit 'Enter' to continue: ")

