# Example showing creation of sphere source and then showing it in a render
# view.
# Pipeline:
# SphereSource --> (Representation, RenderView)

from paraview import servermanager

# We create a server connection only if one isn't already present.
if not servermanager.ActiveConnection:
  servermanager.Connect()

# First create a data source -- in this example we are simply rendering a sphere
# so we create a sphere source.

# Default parameter values can be specified as arguments to the constructor.
sphere = servermanager.sources.SphereSource(Radius=10.5)
# Parameter values can later be accessed/changed as follows:
sphere.PhiResolution = 200
sphere.ThetaResolution = 200

# Now create a view to show the data in.
view = servermanager.CreateRenderView()

# A representation maps the data produced by a source/filter to the view.
# So to show the data in a view, we need to create a representation for it.
repr = servermanager.CreateRepresentation(sphere, view)

# Reset the camera position so that all data is visible
view.ResetCamera()

# Render
view.StillRender()

raw_input("Hit 'Enter' to continue: ")
