# Example illustrating writing out a file series using VTK xml file format.

import exceptions
from paraview import servermanager

# TODO: Set the path to the blow.vtk file
filenamePrefix = "VisExamples/FileSeries"
filenames = []
for i in [0, 1, 2, 3, 4, 5, 6, 9, 11, 15]:
  cur_name = "%s/blow%d.vtk" % (filenamePrefix, i)
  try:
    fp = open(cur_name, "r")
    fp.close()
    filenames.append(cur_name)
  except:
    pass

if not filenames:
  raise exceptions.RuntimeError, \
    "Please set the filenamePrefix to point to directory containing 'blow0.vtk"

# We create a server connection only if one isn't already present.
if not servermanager.ActiveConnection:
  servermanager.Connect()

# Create the reader and set the filename. 
reader = servermanager.sources.LegacyVTKFileReader(FileNames=filenames)

# WarpVector filter tranforms the input geometry using a vector array.
warpVector = servermanager.filters.WarpVector(Input=reader)
warpVector.SelectInputVectors[4] = "displacement"

# Now we want to write the output from warpVector into a file series.

# Essential to call UpdatePipelineInformation() so that reader reads meta data
# before getting the timestep values.
reader.UpdatePipelineInformation()
timesteps = reader.TimestepValues.GetData()
print timesteps
index = 0
for time in timesteps:
  outfile = "/tmp/output%d.vtu" % index

  # Update the reader to the current time-step.
  warpVector.SMProxy.UpdatePipeline(time);

  writer = servermanager.writers.XMLUnstructuredGridWriter(Input = warpVector,\
            FileName=outfile)
  writer.UpdatePipeline()
  index+=1


